Module message

Module message 

Wire protocol message types — enums, payload structs, and conversions.

Modules

client
Messages sent by the client to the gateway.
server
Messages sent by the gateway to the client.

Structs

AgentDetail
Detailed agent information.
AgentInfoRequest
Get detailed info for a specific agent.
AgentList
List of registered agents.
AgentSummary
Summary of a registered agent.
ClearSessionRequest
Clear the session history for an agent.
DownloadRequest
Request download of a model’s files with progress reporting.
GetMemoryRequest
Get a specific memory entry by key.
McpAddRequest
Add an MCP server to config and reload.
McpAdded
MCP server added confirmation.
McpReloaded
MCP servers reloaded confirmation.
McpRemoveRequest
Remove an MCP server from config and reload.
McpRemoved
MCP server removed confirmation.
McpServerList
List of connected MCP servers.
McpServerSummary
Summary of a connected MCP server.
MemoryEntry
A single memory entry.
MemoryList
List of memory entries.
SendRequest
Send a message to an agent and receive a complete response.
SendResponse
Complete response from an agent.
SessionCleared
Session cleared confirmation.
SkillsReloaded
Skills reloaded confirmation.
StreamRequest
Send a message to an agent and receive a streamed response.

Enums

DownloadEvent
Events emitted during a model download.
StreamEvent
Events emitted during a streamed agent response.