Wire protocol message types — enums, payload structs, and conversions.
Modules
Structs
- Agent
Detail - Detailed agent information.
- Agent
Info Request - Get detailed info for a specific agent.
- Agent
List - List of registered agents.
- Agent
Summary - Summary of a registered agent.
- Clear
Session Request - Clear the session history for an agent.
- Download
Request - Request download of a model’s files with progress reporting.
- GetMemory
Request - Get a specific memory entry by key.
- McpAdd
Request - Add an MCP server to config and reload.
- McpAdded
- MCP server added confirmation.
- McpReloaded
- MCP servers reloaded confirmation.
- McpRemove
Request - Remove an MCP server from config and reload.
- McpRemoved
- MCP server removed confirmation.
- McpServer
List - List of connected MCP servers.
- McpServer
Summary - Summary of a connected MCP server.
- Memory
Entry - A single memory entry.
- Memory
List - List of memory entries.
- Send
Request - Send a message to an agent and receive a complete response.
- Send
Response - Complete response from an agent.
- Session
Cleared - Session cleared confirmation.
- Skills
Reloaded - Skills reloaded confirmation.
- Stream
Request - Send a message to an agent and receive a streamed response.
Enums
- Download
Event - Events emitted during a model download.
- Stream
Event - Events emitted during a streamed agent response.